@@ -17,10 +17,7 @@ import aws_cdk.custom_resources._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "cdk-gitlab-runner",
-    "1.71.14",
-    __name__[0:-6],
-    "cdk-gitlab-runner@1.71.14.jsii.tgz",
+    "cdk-gitlab-runner", "1.72.0", __name__[0:-6], "cdk-gitlab-runner@1.72.0.jsii.tgz"
 )
 
 __all__ = [
